@@ -16,20 +16,19 @@
 This module contains code to bootstrap a Zope3 instance.  For example
 it makes sure a root folder exists and creates one if necessary.
 
-$Id: bootstrap.py 97496 2009-03-04 21:24:00Z nadako $
+$Id: bootstrap.py 100899 2009-06-12 18:59:03Z icemac $
 """
 __docformat__ = 'restructuredtext'
 
 
-import transaction
 import logging
+import transaction
 import warnings
-
 import zope.event
 import zope.lifecycleevent
+import zope.processlifetime
 
 from zope.app.publication.zopepublication import ZopePublication
-from zope.app.appsetup import interfaces
 from zope.container.interfaces import INameChooser
 from zope.location.interfaces import ISite
 from zope.security.management import getSecurityPolicy
@@ -93,8 +92,7 @@ def addConfigureUtility(
         warnings.warn("asObject argument is deprecated and will be "
                       "removed in Zope 3.6", DeprecationWarning, 2)
 
-    utility = addUtility(root_folder, utility_type, utility_factory, True,
-                         **kw)
+    utility = addUtility(root_folder, utility_type, utility_factory, **kw)
     root_folder.getSiteManager().registerUtility(utility, interface, name)
     return utility
 
@@ -174,7 +172,7 @@ def bootStrapSubscriber(event):
 
     connection.close()
 
-    zope.event.notify(interfaces.DatabaseOpenedWithRoot(db))
+    zope.event.notify(zope.processlifetime.DatabaseOpenedWithRoot(db))
 
 
 ########################################################################
